==> haskell-swagger2-2.6.1-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 swagger2
version:              2.6.1
visibility:           public
id:                   swagger2-2.6.1-5a2hmegORtU8xUsH8Mz91g
key:                  swagger2-2.6.1-5a2hmegORtU8xUsH8Mz91g
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  add7ef5a343a27a653c70762433a486d
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.0.2/site-local/swagger2-2.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/swagger2-2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.6.1-5a2hmegORtU8xUsH8Mz91g
depends:
    QuickCheck-2.14.2-7IscL6Ui3Th4idiIZNtA9m
    aeson-1.5.6.0-D6JFXMoVVY440Mpm8YlAiW
    aeson-pretty-0.8.9-4FM0CqUjksBBvSARdoqSRK base-4.15.1.0
    base-compat-batteries-0.12.1-HuGFW6fhqNyHbidKrPODvF
    bytestring-0.10.12.1 containers-0.6.4.1
    cookie-0.4.5-B1GcTZOCb6yBzxFcoqFiFA
    generics-sop-0.5.1.2-2vbZE2EqscwJl8mUOyVifJ
    hashable-1.4.0.2-BtUN60XU2rZ3DwXWIBThsB
    http-media-0.8.0.0-9MRmxPWp6Qe8f6HYPOxy2C
    insert-ordered-containers-0.2.5.1-8EfWOSU4dr5GfkHMvTBi5H
    lens-5.1.1-8E4VVgbuyZB1VAyRQnC4Kb mtl-2.2.2
    network-3.1.2.7-8MYdqm3OoEgFMARhN0ME57
    optics-core-0.4.1-D9hVTcZ3gl3BaQvciiwo0B
    optics-th-0.4.1-2r6xZjU9SYYCMYG2kXKtid
    scientific-0.3.7.0-2bBilO5AY4p7o0WHMnmlyC template-haskell-2.17.0.0
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    unordered-containers-0.2.19.1-7SQ4DJN6rki64sevxnHKhZ
    uuid-types-1.0.5-4qkFb4qx5GGHjlKxT1TAny
    vector-0.12.3.1-Im4rxp8YGWIHuHWC3z5rRi

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-swagger2-2.6.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-swagger2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 swagger2
version:              2.6.1
visibility:           public
id:                   swagger2-2.6.1-6pGTeVb8n9dBZPssDiWrvO
key:                  swagger2-2.6.1-6pGTeVb8n9dBZPssDiWrvO
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  deac668d38e5ec0c5fbb371e32646cd4
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.0.2/site-local/swagger2-2.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/swagger2-2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.6.1-6pGTeVb8n9dBZPssDiWrvO
depends:
    QuickCheck-2.14.2-5toH1Vv8ZxxIieqfaLz1c3
    aeson-1.5.6.0-CXf7LknqfgZ2Hfi5jmQpYM
    aeson-pretty-0.8.9-DzZNjhlbS66KcZ9F1MTf7B base-4.15.1.0
    base-compat-batteries-0.12.1-DZWMmW0Mw2bAlISIugBf5H
    bytestring-0.10.12.1 containers-0.6.4.1
    cookie-0.4.5-B1GcTZOCb6yBzxFcoqFiFA
    generics-sop-0.5.1.2-2vbZE2EqscwJl8mUOyVifJ
    hashable-1.4.0.2-2wjc0eIGTr36aGIxRaVTyK
    http-media-0.8.0.0-BpS5PDbWqj5746Xn1tLXDg
    insert-ordered-containers-0.2.5.1-331mxJF1jPk7bTxHPeqI3w
    lens-5.1.1-4ANCjh7E7B9DcPOifqwY15 mtl-2.2.2
    network-3.1.2.7-GkGKOGJhtS7DhusgFes5fA
    optics-core-0.4.1-D9hVTcZ3gl3BaQvciiwo0B
    optics-th-0.4.1-2r6xZjU9SYYCMYG2kXKtid
    scientific-0.3.7.0-8SzWenanV6tE1tEz514SLi template-haskell-2.17.0.0
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    unordered-containers-0.2.19.1-LWNw197ajNNFytwMBd2fIa
    uuid-types-1.0.5-ExFCmTO8LV73L7qa703Ik6
    vector-0.12.3.1-50x5zOQFZ1CIL15Y9vpvyM

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
